Crate spl_merkle_tree_reference

Crate spl_merkle_tree_reference 

Structs

MerkleTree
TreeNode

Constants

EMPTY
MASK
Used for node parity when hashing
MAX_DEPTH
Max depth of the Merkle tree
MAX_SIZE
Max number of concurrent changes to tree supported before having to regenerate proofs

Functions

empty_node
Calculates hash of empty nodes up to level i TODO: cache this
recompute
Recomputes root of the Merkle tree from Node & proof

Type Aliases

Node