Structs
Constants
- EMPTY
- MASK
- Used for node parity when hashing
- MAX_
DEPTH - Max depth of the Merkle tree
- MAX_
SIZE - Max number of concurrent changes to tree supported before having to regenerate proofs
Functions
- empty_
node - Calculates hash of empty nodes up to level i TODO: cache this
- recompute
- Recomputes root of the Merkle tree from Node & proof